@@ -53,7 +53,7 @@ To be set in `tramp-efs-file-name-handler'.")
 (defvar tramp-efs-method-regexp
   (concat tramp-prefix-regexp
 	  (regexp-quote tramp-efs-method)
-	  tramp-postfix-single-method-regexp)
+	  tramp-postfix-method-regexp)
   "Regexp indicating method tag.")
 
 (defun tramp-efs-path-regexp ()
@@ -62,7 +62,7 @@ To be set in `tramp-efs-file-name-handler'.")
 	  (when tramp-efs-method-given
 	    (concat
 	     (regexp-quote tramp-efs-method)
-	     tramp-postfix-single-method-regexp))
+	     tramp-postfix-method-regexp))
 	  "\\(" tramp-user-regexp tramp-postfix-user-regexp "\\)?"
 	  "\\(" tramp-host-with-port-regexp "\\)"
 	  tramp-postfix-host-regexp
@@ -72,7 +72,7 @@ To be set in `tramp-efs-file-name-handler'.")
   "Tramp uses this value for `efs-path-format-string'."
   (concat tramp-prefix-format
 	  (when tramp-efs-method-given
-	    (concat tramp-efs-method tramp-postfix-single-method-format))
+	    (concat tramp-efs-method tramp-postfix-method-format))
 	  "%s" tramp-postfix-user-format
 	  "%s" tramp-postfix-host-format
 	  "%s"))
@@ -81,7 +81,7 @@ To be set in `tramp-efs-file-name-handler'.")
   "Tramp uses this value for `efs-path-format-without-user'."
   (concat tramp-prefix-format
 	  (when tramp-efs-method-given
-	    (concat tramp-efs-method tramp-postfix-single-method-format))
+	    (concat tramp-efs-method tramp-postfix-method-format))
 	  "%s" tramp-postfix-host-format
 	  "%s"))
 
@@ -100,7 +100,7 @@ To be set in `tramp-efs-file-name-handler'.")
 	  (when tramp-efs-method-given
 	    (concat
 	     (regexp-quote tramp-efs-method)
-	     tramp-postfix-single-method-regexp))
+	     tramp-postfix-method-regexp))
 	  "\\(" tramp-user-regexp tramp-postfix-user-regexp "\\)?"
 	  "\\(" tramp-host-with-port-regexp "\\)"
 	  tramp-postfix-host-regexp))
@@ -163,6 +163,10 @@ present for backward compatibility."
    tramp-efs-method
    '((tramp-parse-netrc "~/.netrc"))))
 
+;; If there is URL syntax, `substitute-in-file-name' needs special
+;; handling.
+(put 'substitute-in-file-name 'efs 'tramp-handle-substitute-in-file-name)
+
 (defun tramp-efs-file-name-handler (operation &rest args)
   "Invoke the EFS handler for OPERATION	.	
 First arg specifies the OPERATION, second args is a list of arguments to
