@@ -77,7 +77,7 @@
   "Like `vc-do-command' but invoked for tramp files.
 See `vc-do-command' for more information."
   (save-match-data
-    (and file (setq file (tramp-handle-expand-file-name file)))
+    (and file (setq file (expand-file-name file)))
     (if (not buffer) (setq buffer "*vc*"))
     (if vc-command-messages
 	(message "Running `%s' on `%s'..." command file))
@@ -85,8 +85,7 @@ See `vc-do-command' for more information."
 	  (squeezed nil)
 	  (olddir default-directory)
 	  vc-file status)
-      (let* ((v (tramp-dissect-file-name (tramp-handle-expand-file-name file)))
-	     (multi-method (tramp-file-name-multi-method v))
+      (let* ((v (tramp-dissect-file-name (expand-file-name file)))
 	     (method (tramp-file-name-method v))
 	     (user (tramp-file-name-user v))
 	     (host (tramp-file-name-host v))
@@ -130,12 +129,12 @@ See `vc-do-command' for more information."
 	(save-excursion
 	  (save-window-excursion
 	    ;; Actually execute remote command
-	    (tramp-handle-shell-command
+	    (shell-command
 	     (mapconcat 'tramp-shell-quote-argument
 			(cons command squeezed) " ") t)
 	    ;;(tramp-wait-for-output)
 	    ;; Get status from command
-	    (tramp-send-command multi-method method user host "echo $?")
+	    (tramp-send-command method user host "echo $?")
 	    (tramp-wait-for-output)
 	    ;; Make sure to get status from last line of output.
 	    (goto-char (point-max)) (forward-line -1)
@@ -178,7 +177,6 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
 	  (inhibit-read-only t)
 	  (status 0))
       (let* ((v (when file (tramp-dissect-file-name file)))
-             (multi-method (when file (tramp-file-name-multi-method v)))
              (method (when file (tramp-file-name-method v)))
              (user (when file (tramp-file-name-user v)))
              (host (when file (tramp-file-name-host v)))
@@ -190,7 +188,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
       (let ((w32-quote-process-args t))
         (when (eq okstatus 'async)
           (message "Tramp doesn't do async commands, running synchronously."))
-        (setq status (tramp-handle-shell-command
+        (setq status (shell-command
                       (mapconcat 'tramp-shell-quote-argument
                                  (cons command squeezed) " ") t))
         (when (or (not (integerp status))
@@ -257,8 +255,7 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
   ;; Don't switch to the *vc-info* buffer before running the
   ;; command, because that would change its default directory
   (save-match-data
-    (let* ((v (tramp-dissect-file-name (tramp-handle-expand-file-name file)))
-	   (multi-method (tramp-file-name-multi-method v))
+    (let* ((v (tramp-dissect-file-name (expand-file-name file)))
 	   (method (tramp-file-name-method v))
 	   (user (tramp-file-name-user v))
 	   (host (tramp-file-name-host v))
@@ -284,13 +281,13 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
 	(save-excursion
 	  (save-window-excursion
 	    ;; Actually execute remote command
-	    (tramp-handle-shell-command
+	    (shell-command
 	     (mapconcat 'tramp-shell-quote-argument
 			(append (list command) args (list localname)) " ")
 	     (get-buffer-create"*vc-info*"))
 					;(tramp-wait-for-output)
 	    ;; Get status from command
-	    (tramp-send-command multi-method method user host "echo $?")
+	    (tramp-send-command method user host "echo $?")
 	    (tramp-wait-for-output)
 	    (setq exec-status (read (current-buffer)))
 	    (message "Command %s returned status %d." command exec-status)))
@@ -351,10 +348,10 @@ Since TRAMP doesn't do async commands yet, this function doesn't, either."
 	      ;; The following check is probably to test whether
 	      ;; file-attributes returns correct last modification
 	      ;; times.  This check needs to be changed.
-	      (tramp-get-remote-perl (tramp-file-name-multi-method v)
-				   (tramp-file-name-method v)
-				   (tramp-file-name-user v)
-				   (tramp-file-name-host v)))))
+	      (tramp-get-remote-perl
+	       (tramp-file-name-method v)
+	       (tramp-file-name-user v)
+	       (tramp-file-name-host v)))))
       (setq ad-return-value
             (tramp-vc-workfile-unchanged-p filename want-differences-if-changed))
     ad-do-it))
@@ -414,7 +411,7 @@ filename we are thinking about..."
 	    (nth 2 (file-attributes file)))))
     (if (and uid (/= uid remote-uid))
 	(error "tramp-handle-vc-user-login-name cannot map a uid to a name")
-      (let* ((v (tramp-dissect-file-name (tramp-handle-expand-file-name file)))
+      (let* ((v (tramp-dissect-file-name (expand-file-name file)))
 	     (u (tramp-file-name-user v)))
 	(cond ((stringp u) u)
 	      ((vectorp u) (elt u (1- (length u))))
@@ -445,19 +442,19 @@ filename we are thinking about..."
 (defun tramp-file-owner (filename)
   "Return who owns FILE (user name, as a string)."
   (let ((v (tramp-dissect-file-name 
-	    (tramp-handle-expand-file-name filename))))
-    (if (not (tramp-handle-file-exists-p filename))
+	    (expand-file-name filename))))
+    (if (not (file-exists-p filename))
         nil                             ; file cannot be opened
       ;; file exists, find out stuff
       (save-excursion
         (tramp-send-command
-         (tramp-file-name-multi-method v) (tramp-file-name-method v)
+         (tramp-file-name-method v)
          (tramp-file-name-user v) (tramp-file-name-host v)
          (format "%s -Lld %s"
-                 (tramp-get-ls-command (tramp-file-name-multi-method v)
-                                     (tramp-file-name-method v)
-                                     (tramp-file-name-user v)
-                                     (tramp-file-name-host v))
+                 (tramp-get-ls-command
+		  (tramp-file-name-method v)
+		  (tramp-file-name-user v)
+		  (tramp-file-name-host v))
                  (tramp-shell-quote-argument (tramp-file-name-localname v))))
         (tramp-wait-for-output)
         ;; parse `ls -l' output ...
